@@ -1,13 +1,13 @@
 #! /usr/bin/perl
 
-# $Id: uvt-email-template.pl 39337 2013-05-03 09:42:34Z wsl $
+# $Id: uvt-email-template.pl 39351 2013-05-03 13:49:34Z wsl $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/uvt-email-template/bin/uvt-email-template.pl $
 
 use strict;
 use warnings FATAL => 'all';
 use utf8;
 
-our $PACKAGE;
+our $PACKAGE //= 'uvt-email-template';
 our $pkgdatadir //= our $datadir ? "$datadir/$PACKAGE" : 'share';
 
 use UvT::Email::Template;
